/*
 * Copyright 2016, Cypress Semiconductor Corporation
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Cypress Semiconductor Corporation;
 * the contents of this file may not be disclosed to third parties, copied
 * or duplicated in any form, in whole or in part, without the prior
 * written permission of Cypress Semiconductor Corporation.
 */

/** @file
*
* BLE Observe With White List Patch
*
* Use in place of wiced_bt_ble_observe to be able to hear all adv (non-disc, general, limited)
* and to be able to configure all scan params.
*
* Code was not extensively tested.
*
*
* White list Amendment:
* Pass an array of BD_ADDRs into the addr_array param and specify how long the array is via num_of_white_list_addrs.
* The patch will cycle through the array and add each one to the white list.
*
* Functional when tested on 4343W_AVN on SDK 3.5.2.
*
*/


/******************************************************************************
 *                           Function Prototypes
 ******************************************************************************/

extern BOOLEAN 		btsnd_hcic_ble_set_scan_params (	UINT8 scan_type, UINT16 scan_int, UINT16 scan_win, UINT8 addr_type, UINT8 scan_filter_policy);
extern BOOLEAN 		btsnd_hcic_ble_set_scan_enable (UINT8 scan_enable, UINT8 duplicate);
extern uint8_t		wiced_bt_ble_observe (BOOLEAN start, UINT8 duration, wiced_bt_ble_scan_result_cback_t *p_scan_result_cback);
extern BOOLEAN 		btsnd_hcic_ble_add_white_list (UINT8 addr_type, BD_ADDR bda);

/******************************************************************************
 *                          Function Definitions
 ******************************************************************************/

/* Example White list use:
 *
 * scan_filter_policy = 1
 * num_of_white_list_addrs = 4
 *
 * UINT8 addr_array[num_of_white_list_addrs * BD_ADDR_LEN] = {
 * 		0xaa, 0xbb, 0xcc, 0xdd, 0xee, 0xff,
 *		0x00, 0xbb, 0xcc, 0xdd, 0xee, 0xff,
 *		0xc0, 0xbb, 0xcc, 0xdd, 0xee, 0xff,
 *		0xff, 0xee, 0xdd, 0xcc, 0xbb, 0xc0
 * }
 *
 * Then this patch will push callbacks for the four addresses above only.
 *
 */
void wiced_bt_ble_observe_with_white_list_patch(	UINT8 enable, 						/*1 on, 0 off*/
													UINT8 scan_type,					/*1 active, 0 passive*/
													UINT16 scan_int,					/*in BT slots*/
													UINT16 scan_win,					/*in BT slots*/
													UINT8 scan_filter_policy,			/*1 whitelist filter, 0 no filter*/
													UINT8 duration,						/*max 255 in whole seconds*/
													UINT8 addr_type,					/*BLE_ADDR_PUBLIC, BLE_ADDR_RANDOM, BLE_ADDR_PUBLIC_ID, BLE_ADDR_RANDOM_ID*/
													UINT8 duplicate_filt,				/*1 on, 0 off*/
													UINT8 num_of_white_list_addrs,		/*0 if none*/
													UINT8 * addr_array,					/*array of addresses to filter, NULL if no white list*/
													wiced_bt_ble_scan_result_cback_t *p_scan_result_cback )
{

		if(enable && num_of_white_list_addrs && scan_filter_policy)
		{
			int i;

			for(i = 0; i < num_of_white_list_addrs; i++)
			{
				btsnd_hcic_ble_add_white_list (BLE_ADDR_PUBLIC, addr_array+ (i * BD_ADDR_LEN));
			}
		}


    	wiced_bt_ble_observe( enable, duration, p_scan_result_cback );

    	if(enable)
    	{

			btsnd_hcic_ble_set_scan_enable (0, 0);

			btsnd_hcic_ble_set_scan_params (	scan_type,//BTM_BLE_SCAN_MODE_ACTIVE,
												scan_int,
												scan_win,
												addr_type,
												scan_filter_policy);

			btsnd_hcic_ble_set_scan_enable (1, duplicate_filt);
    	}


}
